@@ -1,12 +1,11 @@
-from typing import Union
-
 from copy import copy
 from pathlib import PosixPath
+from typing import Union
 
 import h5py
 import numpy as np
 import pandas as pd
-from utils_find_1st import find_1st, cmp_larger
+from utils_find_1st import cmp_larger, find_1st
 
 from agora.io.bridge import BridgeH5
 
@@ -34,13 +33,12 @@ class Signal(BridgeH5):
             assert sum(is_bgd) == 0 or sum(is_bgd) == len(
                 dsets
             ), "Trap data and cell data can't be mixed"
-            with h5py.File(self.filename, "r") as f:
-                return [
-                    self.add_name(self.apply_prepost(dset), dset)
-                    for dset in dsets
-                ]
+            return [
+                self.add_name(self.apply_prepost(dset), dset) for dset in dsets
+            ]
 
-        return self.cols_in_mins(self.add_name(df, dsets))
+        # return self.cols_in_mins(self.add_name(df, dsets))
+        return self.add_name(df, dsets)
 
     @staticmethod
     def add_name(df, name):
@@ -88,35 +86,32 @@ class Signal(BridgeH5):
         Apply modifier operations (picker, merger) to a given dataframe.
         """
         merges = self.get_merges()
+        df = self.get_raw(dataset)
+        merged = copy(df)
+        if merges.any():
+            # Split in two dfs, one with rows relevant for merging and one
+            # without them
+            valid_merges = merges[
+                (
+                    merges[:, :, :, None]
+                    == np.array(list(df.index)).T[:, None, :]
+                )
+                .all(axis=(1, 2))
+                .any(axis=1)
+            ]  # Casting allows fast multiindexing
+
+            merged = self.apply_merge(
+                df.loc[map(tuple, valid_merges.reshape(-1, 2))],
+                valid_merges,
+            )
+
+            nonmergeable_ids = df.index.difference(valid_merges.reshape(-1, 2))
+
+            merged = pd.concat(
+                (merged, df.loc[nonmergeable_ids]), names=df.index.names
+            )
+
         with h5py.File(self.filename, "r") as f:
-            df = self.dset_to_df(f, dataset)
-
-            merged = df
-            if merges.any():
-                # Split in two dfs, one with rows relevant for merging and one
-                # without them
-                valid_merges = merges[
-                    (
-                        merges[:, :, :, None]
-                        == np.array(list(df.index)).T[:, None, :]
-                    )
-                    .all(axis=(1, 2))
-                    .any(axis=1)
-                ]  # Casting allows fast multiindexing
-
-                merged = self.apply_merge(
-                    df.loc[map(tuple, valid_merges.reshape(-1, 2))],
-                    valid_merges,
-                )
-
-                nonmergeable_ids = df.index.difference(
-                    valid_merges.reshape(-1, 2)
-                )
-
-                merged = pd.concat(
-                    (merged, df.loc[nonmergeable_ids]), names=df.index.names
-                )
-
             if "modifiers/picks" in f and not skip_pick:
                 picks = self.get_picks(names=merged.index.names)
                 # missing_cells = [i for i in picks if tuple(i) not in
@@ -140,7 +135,7 @@ class Signal(BridgeH5):
                     else:
                         index = pd.Index([], name=merged.index.name)
                     merged = pd.DataFrame([], index=index)
-            return merged
+        return merged
 
     @property
     def datasets(self):
@@ -185,12 +180,6 @@ class Signal(BridgeH5):
     def n_merges(self):
         print("{} merge events".format(len(self.merges)))
 
-    @property
-    def merges(self):
-        with h5py.File(self.filename, "r") as f:
-            dsets = f.visititems(self._if_merges)
-        return dsets
-
     @property
     def picks(self):
         with h5py.File(self.filename, "r") as f:
@@ -208,11 +197,14 @@ class Signal(BridgeH5):
 
         return df
 
-    def get_raw(self, dataset):
+    def get_raw(self, dataset, in_minutes=True):
         try:
             if isinstance(dataset, str):
                 with h5py.File(self.filename, "r") as f:
-                    return self.dset_to_df(f, dataset)
+                    df = self.dset_to_df(f, dataset)
+                    if in_minutes:
+                        df = self.cols_in_mins(df)
+                    return df
             elif isinstance(dataset, list):
                 return [self.get_raw(dset) for dset in dataset]
         except Exception as e:
