@@ -1,32 +1,34 @@
 import itertools
 import logging
+from collections.abc import Iterable
 from time import perf_counter
+from typing import Dict
 
 import h5py
 import numpy as np
 import pandas as pd
-from collections.abc import Iterable
-from typing import Dict
-
-from utils_find_1st import find_1st, cmp_equal
+import yaml
+from utils_find_1st import cmp_equal, find_1st
 
 from agora.io.bridge import BridgeH5
 from agora.io.utils import timed
 
-
 #################### Dynamic version ##################################
 
 
 def load_attributes(file: str, group="/"):
     with h5py.File(file, "r") as f:
         meta = dict(f[group].attrs.items())
+    if "parameters" in meta:
+        meta["parameters"] = yaml.safe_load(meta["parameters"])
     return meta
 
 
 class DynamicWriter:
     data_types = {}
     group = ""
-    compression = None
+    compression = "gzip"
+    compression_opts = 9
 
     def __init__(self, file: str):
         self.file = file
@@ -36,8 +38,10 @@ class DynamicWriter:
         """Append data to existing dataset."""
         try:
             n = len(data)
-        except:
-            # Attributes have no length
+        except Exception as e:
+            logging.debug(
+                "DynamicWriter:Attributes have no length: {}".format(e)
+            )
             n = 1
         if key not in hgroup:
             # TODO Include sparsity check
@@ -49,6 +53,9 @@ class DynamicWriter:
                 maxshape=max_shape,
                 dtype=dtype,
                 compression=self.compression,
+                compression_opts=self.compression_opts
+                if self.compression is not None
+                else None,
             )
             hgroup[key][()] = data
         else:
@@ -58,9 +65,11 @@ class DynamicWriter:
                 dset = hgroup[key]
                 dset.resize(dset.shape[0] + n, axis=0)
                 dset[-n:] = data
-            except:
+            except Exception as e:
                 logging.debug(
-                    "DynamicWriter:Inconsistency between dataset shape and new empty data"
+                    "DynamicWriter:Inconsistency between dataset shape and new empty data: {}".format(
+                        e
+                    )
                 )
         return
 
@@ -164,7 +173,7 @@ class BabyWriter(DynamicWriter):
         "position": ((None,), np.uint16),
         "angles": ((None,), h5py.vlen_dtype(np.float32)),
         "radii": ((None,), h5py.vlen_dtype(np.float32)),
-        "edgemasks": ((max_ncells, max_tps, tile_size, tile_size), np.bool),
+        "edgemasks": ((max_ncells, max_tps, tile_size, tile_size), bool),
         "ellipse_dims": ((None, 2), np.float32),
         "cell_label": ((None,), np.uint16),
         "trap": ((None,), np.uint16),
@@ -187,7 +196,7 @@ class BabyWriter(DynamicWriter):
         max_tps = self.metadata["time_settings/ntimepoints"][0]
         self.datatypes["edgemasks"] = (
             (self.max_ncells, max_tps, tile_size, tile_size),
-            np.bool,
+            bool,
         )
         self._traps_initialised = True
 
@@ -224,7 +233,7 @@ class BabyWriter(DynamicWriter):
         save_complex(current_indices, ix_dset)
 
     def __append_edgemasks(self, hgroup, edgemasks, current_indices):
-        key = "edgemasks"
+        # key = "edgemasks"
         val_dset = hgroup["values"]
         ix_dset = hgroup["indices"]
         existing_indices = load_complex(ix_dset)
@@ -237,7 +246,9 @@ class BabyWriter(DynamicWriter):
         n_tps = val_dset.shape[1] + 1
         n_add_cells = len(missing)
         # RESIZE DATASET FOR TIME and Cells
-        new_shape = (val_dset.shape[0] + n_add_cells, n_tps) + val_dset.shape[2:]
+        new_shape = (val_dset.shape[0] + n_add_cells, n_tps) + val_dset.shape[
+            2:
+        ]
         val_dset.resize(new_shape)
         logging.debug(f"Timing:resizing:{perf_counter() - t}")
         # Writing data
@@ -246,7 +257,11 @@ class BabyWriter(DynamicWriter):
             try:
                 val_dset[ix, n_tps - 1] = mask
             except Exception as e:
-                logging.debug(f"{ix}, {n_tps}, {val_dset.shape}")
+                logging.debug(
+                    "Exception: {}:{}, {}, {}".format(
+                        e, ix, n_tps, val_dset.shape
+                    )
+                )
         # Save the index values
         save_complex(missing, ix_dset)
 
@@ -256,7 +271,7 @@ class BabyWriter(DynamicWriter):
         # DATA is TRAP_IDS, CELL_LABELS, EDGEMASKS in a structured array
         key = "edgemasks"
         val_key = "values"
-        idx_key = "indices"
+        # idx_key = "indices"
         # Length of edgemasks
         traps, cell_labels, edgemasks = data
         n_cells = len(cell_labels)
@@ -315,7 +330,7 @@ class LinearBabyWriter(DynamicWriter):
         "position": ((None,), np.uint16),
         "angles": ((None,), h5py.vlen_dtype(np.float32)),
         "radii": ((None,), h5py.vlen_dtype(np.float32)),
-        "edgemasks": ((None, tile_size, tile_size), np.bool),
+        "edgemasks": ((None, tile_size, tile_size), bool),
         "ellipse_dims": ((None, 2), np.float32),
         "cell_label": ((None,), np.uint16),
         "trap": ((None,), np.uint16),
@@ -365,7 +380,9 @@ class StateWriter(DynamicWriter):
 
     @staticmethod
     def format_values_tpback(states: list, val_name: str):
-        tp_back, trap, value = [[[] for _ in states[0][val_name]] for _ in range(3)]
+        tp_back, trap, value = [
+            [[] for _ in states[0][val_name]] for _ in range(3)
+        ]
 
         lbl_tuples = [
             (tp_back, trap, cell_label)
@@ -399,7 +416,9 @@ class StateWriter(DynamicWriter):
 
     def format_states(self, states: list):
         formatted_state = {"max_lbl": [state["max_lbl"] for state in states]}
-        tp_back, trap, cell_label = self.format_values_tpback(states, "cell_lbls")
+        tp_back, trap, cell_label = self.format_values_tpback(
+            states, "cell_lbls"
+        )
         _, _, prev_feats = self.format_values_tpback(states, "prev_feats")
 
         # Heterogeneous datasets
@@ -410,12 +429,17 @@ class StateWriter(DynamicWriter):
 
         # One entry per cell label - tp_back independent
         for val_name in ("lifetime", "p_was_bud", "p_is_mother"):
-            formatted_state[val_name] = self.format_values_traps(states, val_name)
+            formatted_state[val_name] = self.format_values_traps(
+                states, val_name
+            )
 
         bacum_max = max([len(state["ba_cum"]) for state in states])
 
         formatted_state["ba_cum"] = np.array(
-            [self.pad_if_needed(state["ba_cum"], bacum_max) for state in states]
+            [
+                self.pad_if_needed(state["ba_cum"], bacum_max)
+                for state in states
+            ]
         )
 
         return formatted_state
@@ -488,7 +512,6 @@ class Writer(BridgeH5):
         data : Iterable, default = None
         meta : Dict, default = {}
 
-
         """
         self.id_cache = {}
         with h5py.File(self.filename, "a") as f:
@@ -571,7 +594,9 @@ class Writer(BridgeH5):
             indices[()] = ids
 
     def write_pd(self, f, path, df, **kwargs):
-        values_path = path + "values" if path.endswith("/") else path + "/values"
+        values_path = (
+            path + "values" if path.endswith("/") else path + "/values"
+        )
         if path not in f:
             max_ncells = 2e5
 
@@ -626,7 +651,8 @@ class Writer(BridgeH5):
             df = df[new_tps]
 
             if (
-                not hasattr(self, "id_cache") or not df.index.nlevels in self.id_cache
+                not hasattr(self, "id_cache")
+                or df.index.nlevels not in self.id_cache
             ):  # Use cache dict to store previously-obtained indices
                 self.id_cache[df.index.nlevels] = {}
                 existing_ids = self.get_existing_ids(
@@ -634,7 +660,9 @@ class Writer(BridgeH5):
                 )
                 # Split indices in existing and additional
                 new = df.index.tolist()
-                if df.index.nlevels == 1:  # Cover for cases with a single index
+                if (
+                    df.index.nlevels == 1
+                ):  # Cover for cases with a single index
                     new = [(x,) for x in df.index.tolist()]
                 (
                     found_multis,
@@ -643,13 +671,15 @@ class Writer(BridgeH5):
                     existing=existing_ids,
                     new=new,
                 )
-                found_indices = np.array(locate_indices(existing_ids, found_multis))
+                found_indices = np.array(
+                    locate_indices(existing_ids, found_multis)
+                )
 
                 # We must sort our indices for h5py indexing
                 incremental_existing = np.argsort(found_indices)
-                self.id_cache[df.index.nlevels]["found_indices"] = found_indices[
-                    incremental_existing
-                ]
+                self.id_cache[df.index.nlevels][
+                    "found_indices"
+                ] = found_indices[incremental_existing]
                 self.id_cache[df.index.nlevels]["found_multi"] = found_multis[
                     incremental_existing
                 ]
@@ -663,7 +693,9 @@ class Writer(BridgeH5):
             new_values = df.loc[
                 [
                     _tuple_or_int(x)
-                    for x in self.id_cache[df.index.nlevels]["additional_multis"]
+                    for x in self.id_cache[df.index.nlevels][
+                        "additional_multis"
+                    ]
                 ]
             ].values
             ncells, ntps = f[values_path].shape
@@ -676,7 +708,9 @@ class Writer(BridgeH5):
                     self.id_cache[df.index.nlevels]["found_indices"], tp
                 ] = existing_values[:, i]
             # Add new cells
-            n_newcells = len(self.id_cache[df.index.nlevels]["additional_multis"])
+            n_newcells = len(
+                self.id_cache[df.index.nlevels]["additional_multis"]
+            )
             dset.resize(dset.shape[0] + n_newcells, axis=0)
             dset[ncells:, :] = np.nan
 
@@ -691,7 +725,11 @@ class Writer(BridgeH5):
                 dset.resize(n + n_newcells, axis=0)
                 dset[n:] = (
                     self.id_cache[df.index.nlevels]["additional_multis"][:, i]
-                    if len(self.id_cache[df.index.nlevels]["additional_multis"].shape)
+                    if len(
+                        self.id_cache[df.index.nlevels][
+                            "additional_multis"
+                        ].shape
+                    )
                     > 1
                     else self.id_cache[df.index.nlevels]["additional_multis"]
                 )
@@ -727,21 +765,20 @@ def locate_indices(existing, new):
         if new.shape[1] > 1:
             return [
                 find_1st(
-                    (existing[:, 0] == n[0]) & (existing[:, 1] == n[1]), True, cmp_equal
+                    (existing[:, 0] == n[0]) & (existing[:, 1] == n[1]),
+                    True,
+                    cmp_equal,
                 )
                 for n in new
             ]
         else:
-            return [find_1st(existing[:, 0] == n, True, cmp_equal) for n in new]
+            return [
+                find_1st(existing[:, 0] == n, True, cmp_equal) for n in new
+            ]
     else:
         return []
 
 
-# def tuple_or_int(x):
-#     if isinstance(x, Iterable):
-#         return tuple(x)
-#     else:
-#         return x
 def _tuple_or_int(x):
     # Convert tuple to int if it only contains one value
     if len(x) == 1:
